API docs for “spamfighter.txjsonrpc.jsonrpclib”

# Module s.t.jsonrpclib

Part of spamfighter.txjsonrpc View Source

Requires simplejson; can be downloaded from http://cheeseshop.python.org/pypi/simplejson

Class | Fault | Undocumented
Class | NoSuchFunction | There is no function by the given name.
Function | dumps | Undocumented
Function | loads | Undocumented
Class | SimpleParser | Undocumented
Class | SimpleUnmarshaller | Undocumented
Function | getparser | Undocumented
Class | Transport | Handles an HTTP transaction to an XML-RPC server.
Class | ServerProxy | No class docstring; 1/2 methods documented

def dumps(obj, **kws): (source)
Undocumented
def loads(string, **kws): (source)
Undocumented
def getparser(): (source)
Undocumented